PyXMake Developer Guide: PyXMake.Tools.Utility.UpdateZIP Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.UpdateZIP Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.UpdateZIP:

## Public Member Functions
| __init__ (self, zipname, zipdata=None, outpath=os.getcwd(), exclude=[], update=True, **kwargs)
| __enter__ (self)
| __exit__ (self, etype, value, traceback)

## Static Public Member Functions
| create (filename)

## Public Attributes
| ZipName = zipname
| ZipData = copy.deepcopy(zipdata)
| buffer = open(os.path.join(os.getcwd(), self.ZipName), 'wb+')
| Output = io.BytesIO();
| OutputPath = outpath
| ExcludeFiles = exclude
| IgnoreExtension = kwargs.get("ignore_extension",(".zip", ".obj"))
| Update = update

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Context manager for update an existing ZIP folder

    @author: Marc Garbade

Inherited from built-in object.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.UpdateZIP.__init__ | ( |  | self,
|  |  | zipname,
|  |  | zipdata = None,
|  |  | outpath = os.getcwd(),
|  |  | exclude = [],
|  |  | update = True,
|  | ** | kwargs )

Definition at line 374 of file Utility.py.

## Member Function Documentation

## ◆ __enter__()

PyXMake.Tools.Utility.UpdateZIP.__enter__ | ( |  | self | ) |

Definition at line 403 of file Utility.py.

## ◆ __exit__()

PyXMake.Tools.Utility.UpdateZIP.__exit__ | ( |  | self,
|  |  | etype,
|  |  | value,
|  |  | traceback )

Definition at line 413 of file Utility.py.

## ◆ create()

PyXMake.Tools.Utility.UpdateZIP.create | ( |  | filename | ) |
| static

    Create a new compatible empty archive

    @author: Marc Garbade

Definition at line 360 of file Utility.py.

## Member Data Documentation

## ◆ buffer

PyXMake.Tools.Utility.UpdateZIP.buffer = open(os.path.join(os.getcwd(), self.ZipName), 'wb+')

Definition at line 379 of file Utility.py.

## ◆ ExcludeFiles

PyXMake.Tools.Utility.UpdateZIP.ExcludeFiles = exclude

Definition at line 398 of file Utility.py.

## ◆ IgnoreExtension

PyXMake.Tools.Utility.UpdateZIP.IgnoreExtension = kwargs.get("ignore_extension",(".zip", ".obj"))

Definition at line 399 of file Utility.py.

## ◆ Output

PyXMake.Tools.Utility.UpdateZIP.Output = io.BytesIO();

Definition at line 396 of file Utility.py.

## ◆ OutputPath

PyXMake.Tools.Utility.UpdateZIP.OutputPath = outpath

Definition at line 397 of file Utility.py.

## ◆ Update

PyXMake.Tools.Utility.UpdateZIP.Update = update

Definition at line 401 of file Utility.py.

## ◆ ZipData

PyXMake.Tools.Utility.UpdateZIP.ZipData = copy.deepcopy(zipdata)

Definition at line 376 of file Utility.py.

## ◆ ZipName

PyXMake.Tools.Utility.UpdateZIP.ZipName = zipname

Definition at line 375 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py